<?php

namespace Drupal\notebook\Controller;

use Drupal\Component\Render\FormattableMarkup;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Database\Connection;
use Drupal\Core\Link;
use Drupal\Core\Render\Markup;
use Drupal\Core\Render\RendererInterface;
use Drupal\Core\StringTranslation\TranslationInterface;
use Drupal\Core\Url;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Class Display.
 *
 * @package Drupal\notebook\Controller
 */
class DisplayNotes extends ControllerBase {

  /**
   * The database connection.
   *
   * @var \Drupal\Core\Database\Connection
   */
  protected $database;

  /**
   * The Renderer Interface.
   *
   * @var Drupal\Core\Render\RendererInterface
   */
  protected $renderer;

  /**
   * The Translation Interface.
   *
   * @var Drupal\Core\StringTranslation\TranslationInterface
   */
  protected $translation;

  /**
   * Constructs a new  object.
   *
   * @param \Drupal\Core\Database\Connection $database
   *   The database connection.
   * @param Drupal\Core\Render\RendererInterface $renderer
   *   The Render Interface.
   * @param Drupal\Core\StringTranslation\TranslationInterface $translation
   *   The Translation Interface.
   */
  public function __construct(Connection $database, RendererInterface $renderer, TranslationInterface $translation) {
    $this->database = $database;
    $this->renderer = $renderer;
    $this->translation = $translation;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('database'),
      $container->get('renderer'),
      $container->get('string_translation')
    );
  }

  /**
   * Show data.
   *
   * @return string
   *   Return Table format data.
   */
  public function showNotes() {
    $build['#attached']['library'][] = 'notebook/notebook';
    $result = "";
    $select = $this->database->select('notebook_table', 'n');
    $select->Fields('n');
    $pager = $select->extend('Drupal\Core\Database\Query\PagerSelectExtender')
      ->limit(4);
    $result = $pager->execute()->fetchAll();
    if ($result != NULL) {
      $rows = [];
      foreach ($result as $row) {
        $date_time = $row->created;
        $timestamp = strtotime($date_time);
        $date = date('F j, Y', $timestamp);
        $url_show = Url::fromRoute('see_note_page', ['show_id' => $row->notes_id], []);
        $linkShow = Link::FromTextAndUrl('View', $url_show);
        $delete = new FormattableMarkup('<a href="javascript:void(0);" class = "delete-note" id = "delete-note" data-id = "' . $row->notes_id . '" >Remove</a>', []);
        $linkDelete = $this->translation->translate('@deletelink', ['@deletelink' => $delete]);
        $rows[] = [
          'data' => [
            'notes_id' => $row->notes_id,
            'subject' => $row->subject,
            'created' => $date,
            'show' => $linkShow->toString(),
            'delete' => $linkDelete,
          ],
        ];
      }

      $build['table'] = [
        '#type'  => 'table',
        '#rows' => $rows,
        '#empty' => $this->t('No data available'),
        '#attributes' => [
          'class' => ['table'],
        ],
        '#prefix' => '<div class="table-responsive">',
        '#suffix' => '</div>',
      ];
      $build['pager'] = [
        '#type' => 'pager',
      ];
      // Render the table using the render() function.
      $table_output = $this->renderer->render($build);
      // Create an array for your output.
      $output = [
        '#markup' => Markup::create($table_output),
      ];
      return [
        $output,
      ];

    }
    else {
      $output = [
        '#markup' => Markup::create("<div class = 'message'>No records found.</div>"),
      ];
      return $output;
    }
  }

}
