<?php

namespace Drupal\notebook\Controller;

use Drupal\Core\DependencyInjection\ClassResolverInterface;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Form\FormBuilderInterface;
use Drupal\Core\Render\Markup;
use Drupal\Core\Render\RendererInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Class Display.
 *
 * @package Drupal\notebook\Controller
 */
class NoteBook extends ControllerBase {

  /**
   * The ClassResolver Interface Variable.
   *
   * @var Drupal\Core\DependencyInjection\ClassResolverInterface
   */
  protected $classResolver;

  /**
   * The form builder.
   *
   * @var \Drupal\Core\Form\FormBuilderInterface
   */
  protected $formBuilder;

  /**
   * The Renderer Interface.
   *
   * @var Drupal\Core\Render\RendererInterface
   */
  protected $renderer;

  /**
   * Constructs a new object in NoteBook.
   *
   * @param Drupal\Core\DependencyInjection\ClassResolverInterface $classResolver
   *   The ClassResolver.
   * @param \Drupal\Core\Form\FormBuilderInterface $formBuilder
   *   The database connection.
   * @param Drupal\Core\Render\RendererInterface $renderer
   *   The Render Interface.
   */
  public function __construct(ClassResolverInterface $classResolver, FormBuilderInterface $formBuilder, RendererInterface $renderer) {
    $this->classResolver = $classResolver;
    $this->formBuilder = $formBuilder;
    $this->renderer = $renderer;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('class_resolver'),
      $container->get('form_builder'),
      $container->get('renderer')
    );
  }

  /**
   * NoteBook Page.
   *
   * @return string
   *   Return Table format data.
   */
  public function noteBookPage() {
    $id = "notebook-page";
    $form = $this->formBuilder()->getForm('\Drupal\notebook\Form\addNoteForm');
    $displayNotesController = $this->classResolver->getInstanceFromDefinition('Drupal\notebook\Controller\DisplayNotes');
    $renderedController = $displayNotesController->showNotes();
    $renderForm = $this->renderer->render($form);
    $renderNotes = $this->renderer->render($renderedController);
    $output1 = [
      '#markup' => Markup::create($renderForm),
    ];
    $output2 = [
      '#markup' => Markup::create($renderNotes),
    ];
    return [
      '#theme' => 'notebook_page',
      '#output1' => $output1,
      '#output2' => $output2,
      '#output_id' => $id,
    ];

  }

}
